@@ -189,7 +189,7 @@ class AbstractBackend(QtCore.QObject):
         if (self.__playing):
             pos, total = self.__position
 
-            if (pos < 3):
+            if (pos < 3 or total <= 0):
                 pos, total = self._get_position()
                 timestamp = time.time()
                 beginpos = pos
