@@ -8,12 +8,13 @@ class PandaException( Exception ):
 
 class RadioPlayer(QtCore.QThread):
 	__pyqtSignals__ = ( "PlayNext", "LoveHate", "songs", "stations", "deleted", "tired", "authSuccess", \
-		"stationCreated", "authFail", "duration" )
+		"stationCreated", "authFail", "duration", "state(QString)" )
 	
 	def __init__( self, Parent=None ):
 		self.timer = None
 		self.playing = 0
 		self.skip = False
+		self.eof = False
 		self.run = 1
 		self.user = ""
 		self.password = ""
@@ -40,6 +41,7 @@ class RadioPlayer(QtCore.QThread):
 			from libpiano.OSSOBackend import OSSOBackend
 			self.player = OSSOBackend()
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.onPlayBackEnded)
+		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("pos_changed(int,int)"), self.updateTime)
 		self.stop = True
 		self.playStation = 0
@@ -47,13 +49,12 @@ class RadioPlayer(QtCore.QThread):
 		self.curStation = ""
 		self.playlist = []
 
-		fmt = 'mp3'
-		self.pandora = Pandora( fmt )
+		self.format = 'mp3'
+		self.pandora = Pandora( self.format )
 
 		QtCore.QThread.__init__(self)
 
 	def run(self):
-		self.pandora.sync()
 		while self.run:
 			if self.loveHateSong:
 				self.loveHateSong = 0
@@ -107,6 +108,12 @@ class RadioPlayer(QtCore.QThread):
 			if self.duration > 0:
 				self.emit(QtCore.SIGNAL("duration"))
 
+	def stateChange( self, state ):
+		if state == 2:
+			self.emit(QtCore.SIGNAL("state(QString)"),"pause")
+		elif state == 1:
+			self.emit(QtCore.SIGNAL("state(QString)"),"play")
+
 	def createStation( self ):
 		ret = self.pandora.createStation( self.createStationId )
 		self.playStation = ret["stationId"]
@@ -130,8 +137,10 @@ class RadioPlayer(QtCore.QThread):
 		self.play( item[0], item[1] )
 
 	def play( self, url, item ):
-		time.sleep( 0.5 )
+		time.sleep ( 2 )
 		self.player.load_audio(url)
+		if self.eof:
+			self.eof = False
 
 	def stopPlayBack ( self,state=None ):
 		if state == 'pause':
@@ -151,9 +160,11 @@ class RadioPlayer(QtCore.QThread):
 				self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def onPlayBackEnded( self ):
-		if self.skip:
-			self.skip = False
-		self.emit(QtCore.SIGNAL("PlayNext"))
+		if not self.eof:
+			if self.skip:
+				self.skip = False
+			self.eof = True
+			self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def LoveHate( self ):
 		self.respLH = self.pandora.addFeedback( self.curSong[1]["stationId"], self.curSong, self.loveHateRating )
@@ -179,7 +190,7 @@ class RadioPlayer(QtCore.QThread):
 		if self.curStation == "":
 			raise PandaException()
 		items = []
-		fragment = self.pandora.getFragment( self.curStation )
+		fragment = self.pandora.getFragment( self.curStation, self.format )
 		for s in fragment:
 			#print s
 			#print "\n"
